@@ -1,10 +1,10 @@
 ;;; ob-msc.el --- Babel Functions for Mscgen         -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2010-2017 Free Software Foundation, Inc.
+;; Copyright (C) 2010-2020 Free Software Foundation, Inc.
 
 ;; Author: Juan Pechiar
 ;; Keywords: literate programming, reproducible research
-;; Homepage: http://orgmode.org
+;; Homepage: https://orgmode.org
 
 ;; This file is part of GNU Emacs.
 
@@ -68,8 +68,7 @@ mscgen supported formats."
   (let* ((out-file (or (cdr (assq :file params)) "output.png" ))
          (filetype (or (cdr (assq :filetype params)) "png" )))
     (unless (cdr (assq :file params))
-      (error "
-ERROR: no output file specified.  Add \":file name.png\" to the src header"))
+      (error "ERROR: no output file specified.  Add \":file name.png\" to the src header"))
     (org-babel-eval (concat "mscgen -T " filetype " -o " out-file) body)
     nil)) ;; signal that output has already been written to file
 
@@ -79,6 +78,4 @@ ERROR: no output file specified.  Add \":file name.png\" to the src header"))
 
 (provide 'ob-mscgen)
 
-
-
 ;;; ob-msc.el ends here
