@@ -1,6 +1,6 @@
 ;;; test-org-clock.el --- Tests for org-clock.el
 
-;; Copyright (C) 2012, 2014, 2015  Nicolas Goaziou
+;; Copyright (C) 2012, 2014, 2015, 2019  Nicolas Goaziou
 
 ;; Author: Nicolas Goaziou <n.goaziou at gmail dot com>
 
@@ -49,8 +49,8 @@ Return the clock line as a string."
   (let* ((beg (org-test-clock-create-timestamp input1 t t))
          (end (and input2 (org-test-clock-create-timestamp input2 t t)))
          (sec-diff (and input2
-			(floor (- (org-time-string-to-seconds end)
-				  (org-time-string-to-seconds beg))))))
+                        (floor (- (org-time-string-to-seconds end)
+                                  (org-time-string-to-seconds beg))))))
     (concat org-clock-string " " beg
             (when end
               (concat "--" end " => "
@@ -82,7 +82,7 @@ the buffer."
         ;; Skip caption.
         (when (looking-at "#\\+CAPTION:") (forward-line))
         (buffer-substring-no-properties
-	 (point) (progn (search-forward "#+END:") (line-end-position 0))))
+         (point) (progn (search-forward "#+END:") (line-end-position 0))))
     ;; Remove clocktable.
     (delete-region (point) (search-forward "#+END:\n"))))
 
@@ -273,6 +273,30 @@ the buffer."
 
 ;;; Clocktable
 
+(ert-deftest test-org-clock/clocktable/insert ()
+  "Test insert clocktable dynamic block with `org-dynamic-block-insert-dblock'."
+  (should
+   (equal
+    "| Headline     | Time   |
+|--------------+--------|
+| *Total time* | *1:00* |
+|--------------+--------|
+| H1           | 1:00   |"
+    (org-test-with-temp-text "* H1\n<point>"
+      (insert (org-test-clock-create-clock ". 1:00" ". 2:00"))
+
+      (goto-line 2)
+      (require 'org-clock)
+      (org-dynamic-block-insert-dblock "clocktable")
+
+      (goto-line 1)
+      (unwind-protect
+	  (save-excursion
+	    (when (search-forward "#+CAPTION:") (forward-line))
+	    (buffer-substring-no-properties
+	     (point) (progn (search-forward "#+END:") (line-end-position 0))))
+	(delete-region (point) (search-forward "#+END:\n")))))))
+
 (ert-deftest test-org-clock/clocktable/ranges ()
   "Test ranges in Clock table."
   ;; Relative time: Previous two days.
@@ -322,9 +346,9 @@ the buffer."
       (insert (org-test-clock-create-clock "-2d 15:00" "-2d 18:00"))
       (test-org-clock-clocktable-contents ":block untilnow :indent nil")))))
 
-(ert-deftest test-org-clock/clocktable/tags ()
-  "Test \":tags\" parameter in Clock table."
-  ;; Test tag filtering.
+(ert-deftest test-org-clock/clocktable/match ()
+  "Test \":match\" parameter in Clock table."
+  ;; Test match filtering.
   (should
    (equal
     "| Headline     | Time   |      |
@@ -336,7 +360,22 @@ the buffer."
       (insert (org-test-clock-create-clock ". 1:00" ". 2:00"))
       (goto-line 4)
       (insert (org-test-clock-create-clock ". 2:00" ". 4:00"))
-      (test-org-clock-clocktable-contents ":tags \"tag\" :indent nil")))))
+      (test-org-clock-clocktable-contents ":match \"tag\" :indent nil")))))
+
+(ert-deftest test-org-clock/clocktable/tags ()
+  "Test \":tags\" parameter in Clock table."
+  ;; Test tags column.
+  (should
+   (equal
+    "| Tags | Headline     | Time   |      |
+|------+--------------+--------+------|
+|      | *Total time* | *1:00* |      |
+|------+--------------+--------+------|
+| tag  | H1           |        | 1:00 |"
+    (org-test-with-temp-text "** H1 :tag:\n\n*** H2 \n<point>"
+      (insert (org-test-clock-create-clock ". 1:00" ". 2:00"))
+      (goto-line 4)
+      (test-org-clock-clocktable-contents ":tags t :indent nil")))))
 
 (ert-deftest test-org-clock/clocktable/scope ()
   "Test \":scope\" parameter in Clock table."
@@ -354,18 +393,18 @@ the buffer."
         "* Test
 CLOCK: [2012-03-29 Thu 8:00]--[2012-03-29 Thu 16:40] => 8:40"
       (test-org-clock-clocktable-contents ":scope file-with-archives"
-	  "#+TBLFM: $3=string(\"foo\")"))))
+                                          "#+TBLFM: $3=string(\"foo\")"))))
   ;; Test "function" scope.
   (should
    (string-match-p
     (regexp-quote "| ALL *Total time* | *1:00* |")
     (org-test-with-temp-text-in-file
-	"* Test
+        "* Test
 CLOCK: [2012-03-29 Thu 16:00]--[2012-03-29 Thu 17:00] =>  1:00"
       (let ((the-file (buffer-file-name)))
-	(org-test-with-temp-text-in-file ""
-	  (test-org-clock-clocktable-contents
-	      (format ":scope (lambda () (list %S))" the-file))))))))
+        (org-test-with-temp-text-in-file ""
+          (test-org-clock-clocktable-contents
+           (format ":scope (lambda () (list %S))" the-file))))))))
 
 (ert-deftest test-org-clock/clocktable/maxlevel ()
   "Test \":maxlevel\" parameter in Clock table."
@@ -394,7 +433,7 @@ CLOCK: [2016-12-28 Wed 13:09]--[2016-12-28 Wed 15:09] =>  2:00"
 CLOCK: [2016-12-28 Wed 11:09]--[2016-12-28 Wed 15:09] =>  4:00
 ** Bar
 CLOCK: [2016-12-28 Wed 13:09]--[2016-12-28 Wed 15:09] =>  2:00"
-	    (test-org-clock-clocktable-contents ":maxlevel 2"))))
+            (test-org-clock-clocktable-contents ":maxlevel 2"))))
   (should
    (equal "| Headline     | Time   |
 |--------------+--------|
@@ -406,7 +445,7 @@ CLOCK: [2016-12-28 Wed 13:09]--[2016-12-28 Wed 15:09] =>  2:00"
 CLOCK: [2016-12-28 Wed 11:09]--[2016-12-28 Wed 15:09] =>  4:00
 ** Bar
 CLOCK: [2016-12-28 Wed 13:09]--[2016-12-28 Wed 15:09] =>  2:00"
-	    (test-org-clock-clocktable-contents ":maxlevel 1"))))
+            (test-org-clock-clocktable-contents ":maxlevel 1"))))
   ;; Special ":maxlevel 0" case: only report total file time.
   (should
    (equal "| Headline     | Time   |
@@ -418,7 +457,7 @@ CLOCK: [2016-12-28 Wed 13:09]--[2016-12-28 Wed 15:09] =>  2:00"
 CLOCK: [2016-12-28 Wed 11:09]--[2016-12-28 Wed 15:09] =>  4:00
 ** Bar
 CLOCK: [2016-12-28 Wed 13:09]--[2016-12-28 Wed 15:09] =>  2:00"
-	    (test-org-clock-clocktable-contents ":maxlevel 0")))))
+            (test-org-clock-clocktable-contents ":maxlevel 0")))))
 
 (ert-deftest test-org-clock/clocktable/formula ()
   "Test \":formula\" parameter in Clock table."
@@ -463,8 +502,8 @@ CLOCK: [2016-12-28 Wed 13:09]--[2016-12-28 Wed 15:09] =>  2:00"
 | \\_  sub3      |        | 0:30 |      |  50.0 |
 | \\_    subsub1 |        |      | 0:15 |  25.0 |
 | \\_    subsub1 |        |      | 0:15 |  25.0 |"
-	  (org-test-with-temp-text
-	      "* foo
+          (org-test-with-temp-text
+              "* foo
 ** sub
    :LOGBOOK:
    CLOCK: [2017-03-18 Sat 15:00]--[2017-03-18 Sat 15:15] =>  0:15
@@ -482,7 +521,7 @@ CLOCK: [2016-12-28 Wed 13:09]--[2016-12-28 Wed 15:09] =>  2:00"
     :LOGBOOK:
     CLOCK: [2017-03-18 Sat 14:00]--[2017-03-18 Sat 14:15] =>  0:15
     :END:"
-	    (test-org-clock-clocktable-contents ":maxlevel 3 :formula %")))))
+            (test-org-clock-clocktable-contents ":maxlevel 3 :formula %")))))
 
 (ert-deftest test-org-clock/clocktable/lang ()
   "Test \":lang\" parameter in Clock table."
@@ -538,124 +577,86 @@ CLOCK: [2016-12-28 Wed 13:09]--[2016-12-28 Wed 15:09] =>  2:00"
   ;; If there is no file attached to the document, link directly to
   ;; the headline.
   (should
-   (equal
-    "| Headline     | Time    |
-|--------------+---------|
-| *Total time* | *26:00* |
-|--------------+---------|
-| [[Foo][Foo]]          | 26:00   |"
-    (org-test-with-temp-text
-	"* Foo
+   (string-match-p "| +\\[\\[\\*Foo]\\[Foo]] +| 26:00 +|"
+		   (org-test-with-temp-text
+		       "* Foo
 CLOCK: [2016-12-27 Wed 13:09]--[2016-12-28 Wed 15:09] => 26:00"
-      (test-org-clock-clocktable-contents ":link t"))))
+		     (test-org-clock-clocktable-contents ":link t"))))
   ;; Otherwise, link to the headline in the current file.
   (should
-   (equal
-    "| Headline     | Time    |
-|--------------+---------|
-| *Total time* | *26:00* |
-|--------------+---------|
-| [[file:filename::Foo][Foo]]          | 26:00   |"
-    (org-test-with-temp-text-in-file
-	"* Foo
+   (string-match-p
+    "| \\[\\[file:filename::\\*Foo]\\[Foo]] +| 26:00 +|"
+    (org-test-with-temp-text
+	(org-test-with-temp-text-in-file
+	    "* Foo
 CLOCK: [2016-12-27 Wed 13:09]--[2016-12-28 Wed 15:09] => 26:00"
-      (let ((file (buffer-file-name)))
-	(replace-regexp-in-string
-	 (regexp-quote file) "filename"
-	 (test-org-clock-clocktable-contents ":link t"))))))
+	  (let ((file (buffer-file-name)))
+	    (replace-regexp-in-string
+	     (regexp-quote file) "filename"
+	     (test-org-clock-clocktable-contents ":link t :lang en"))))
+      (org-table-align)
+      (buffer-substring-no-properties (point-min) (point-max)))))
   ;; Ignore TODO keyword, priority cookie, COMMENT and tags in
   ;; headline.
   (should
-   (equal
-    "| Headline     | Time    |
-|--------------+---------|
-| *Total time* | *26:00* |
-|--------------+---------|
-| [[Foo][Foo]]          | 26:00   |"
+   (string-match-p
+    "| \\[\\[\\*Foo]\\[Foo]] +| 26:00 +|"
     (org-test-with-temp-text
 	"* TODO Foo
 CLOCK: [2016-12-27 Wed 13:09]--[2016-12-28 Wed 15:09] => 26:00"
-      (test-org-clock-clocktable-contents ":link t"))))
+      (test-org-clock-clocktable-contents ":link t :lang en"))))
   (should
-   (equal
-    "| Headline     | Time    |
-|--------------+---------|
-| *Total time* | *26:00* |
-|--------------+---------|
-| [[Foo][Foo]]          | 26:00   |"
+   (string-match-p
+    "| \\[\\[\\*Foo]\\[Foo]] +| 26:00 +|"
     (org-test-with-temp-text
 	"* [#A] Foo
 CLOCK: [2016-12-27 Wed 13:09]--[2016-12-28 Wed 15:09] => 26:00"
-      (test-org-clock-clocktable-contents ":link t"))))
+      (test-org-clock-clocktable-contents ":link t :lang en"))))
   (should
-   (equal
-    "| Headline     | Time    |
-|--------------+---------|
-| *Total time* | *26:00* |
-|--------------+---------|
-| [[Foo][Foo]]          | 26:00   |"
+   (string-match-p
+    "| \\[\\[\\*Foo]\\[Foo]] +| 26:00 +|"
     (org-test-with-temp-text
 	"* COMMENT Foo
 CLOCK: [2016-12-27 Wed 13:09]--[2016-12-28 Wed 15:09] => 26:00"
       (test-org-clock-clocktable-contents ":link t"))))
   (should
-   (equal
-    "| Headline     | Time    |
-|--------------+---------|
-| *Total time* | *26:00* |
-|--------------+---------|
-| [[Foo][Foo]]          | 26:00   |"
+   (string-match-p
+    "| \\[\\[\\*Foo]\\[Foo]] +| 26:00 +|"
     (org-test-with-temp-text
 	"* Foo :tag:
 CLOCK: [2016-12-27 Wed 13:09]--[2016-12-28 Wed 15:09] => 26:00"
-      (test-org-clock-clocktable-contents ":link t"))))
+      (test-org-clock-clocktable-contents ":link t :lang en"))))
   ;; Remove statistics cookie from headline description.
   (should
-   (equal
-    "| Headline     | Time    |
-|--------------+---------|
-| *Total time* | *26:00* |
-|--------------+---------|
-| [[Foo][Foo]]          | 26:00   |"
+   (string-match-p
+    "| \\[\\[\\*Foo]\\[Foo]] +| 26:00 +|"
     (org-test-with-temp-text
 	"* Foo [50%]
 CLOCK: [2016-12-27 Wed 13:09]--[2016-12-28 Wed 15:09] => 26:00"
-      (test-org-clock-clocktable-contents ":link t"))))
+      (test-org-clock-clocktable-contents ":link t :lang en"))))
   (should
-   (equal
-    "| Headline     | Time    |
-|--------------+---------|
-| *Total time* | *26:00* |
-|--------------+---------|
-| [[Foo][Foo]]          | 26:00   |"
+   (string-match-p
+    "| \\[\\[\\*Foo]\\[Foo]] +| 26:00 +|"
     (org-test-with-temp-text
 	"* Foo [1/2]
 CLOCK: [2016-12-27 Wed 13:09]--[2016-12-28 Wed 15:09] => 26:00"
-      (test-org-clock-clocktable-contents ":link t"))))
+      (test-org-clock-clocktable-contents ":link t :lang en"))))
   ;; Replace links with their description, or turn them into plain
   ;; links if there is no description.
   (should
-   (equal
-    "| Headline     | Time    |
-|--------------+---------|
-| *Total time* | *26:00* |
-|--------------+---------|
-| [[Foo %5B%5Bhttps://orgmode.org%5D%5BOrg mode%5D%5D][Foo Org mode]] | 26:00   |"
+   (string-match-p
+    "| \\[\\[\\*Foo \\\\\\[\\\\\\[https://orgmode\\.org\\\\]\\\\\\[Org mode\\\\]\\\\]]\\[Foo Org mode]] +| 26:00 +|"
     (org-test-with-temp-text
 	"* Foo [[https://orgmode.org][Org mode]]
 CLOCK: [2016-12-27 Wed 13:09]--[2016-12-28 Wed 15:09] => 26:00"
-      (test-org-clock-clocktable-contents ":link t"))))
+      (test-org-clock-clocktable-contents ":link t :lang en"))))
   (should
-   (equal
-    "| Headline                | Time    |
-|-------------------------+---------|
-| *Total time*            | *26:00* |
-|-------------------------+---------|
-| [[Foo %5B%5Bhttps://orgmode.org%5D%5D][Foo https://orgmode.org]] | 26:00   |"
+   (string-match-p
+    "| \\[\\[\\*Foo \\\\\\[\\\\\\[https://orgmode\\.org\\\\]\\\\]]\\[Foo https://orgmode\\.org]] +| 26:00 +|"
     (org-test-with-temp-text
 	"* Foo [[https://orgmode.org]]
 CLOCK: [2016-12-27 Wed 13:09]--[2016-12-28 Wed 15:09] => 26:00"
-      (test-org-clock-clocktable-contents ":link t")))))
+      (test-org-clock-clocktable-contents ":link t :lang en")))))
 
 (ert-deftest test-org-clock/clocktable/compact ()
   "Test \":compact\" parameter in Clock table."
@@ -833,136 +834,370 @@ CLOCK: [2016-12-28 Wed 13:09]--[2016-12-28 Wed 13:09] =>  0:00"
   ;; Regression test: week crossing month boundary before :wstart
   ;; day-of-week.
   (should
-   (equal "
-Weekly report starting on: [2017-09-25 Mon]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *1:00* |
-|--------------+--------|
-| Foo          | 1:00   |"
-	  (org-test-with-temp-text
-	      "* Foo
+   (string-match-p
+    "
+.*?\\[2017-09-25 .*
+.*
+.*
+|.*?| \\*1:00\\* |
+.*
+| Foo +| 1:00 +|"
+    (org-test-with-temp-text
+	"* Foo
 CLOCK: [2017-09-30 Sat 12:00]--[2017-09-30 Sat 13:00] =>  1:00
 CLOCK: [2017-10-01 Sun 11:00]--[2017-10-01 Sun 13:00] =>  2:00
 CLOCK: [2017-10-02 Mon 11:00]--[2017-10-02 Mon 14:00] =>  3:00"
-	    (let ((system-time-locale "en_US"))
-	      (test-org-clock-clocktable-contents
-		  ":step week :block 2017-09 :stepskip0 t")))))
+      (let ((system-time-locale "en_US"))
+	(test-org-clock-clocktable-contents
+	    ":step week :block 2017-09 :stepskip0 t")))))
   (should
-   (equal "
-Weekly report starting on: [2017-10-01 Sun]
-| Headline     | Time   |
+   (string-match-p
+    "
+.*?\\[2017-10-01 .*
+.*
+.*
+|.*?| \\*2:00\\* |
+.*
+| Foo +| 2:00   |
+
+.*?\\[2017-10-02 .*
+.*
+.*
+|.*?| \\*7:00\\* |
+.*
+| Foo +| 7:00 +|
+
+.*?\\[2017-10-09 .*
+.*
+.*
+|.*?| \\*5:00\\* |
+.*
+| Foo +| 5:00 +|
+"
+    (org-test-with-temp-text
+	"* Foo
+CLOCK: [2017-09-30 Sat 12:00]--[2017-09-30 Sat 13:00] =>  1:00
+CLOCK: [2017-10-01 Sun 11:00]--[2017-10-01 Sun 13:00] =>  2:00
+CLOCK: [2017-10-02 Mon 11:00]--[2017-10-02 Mon 14:00] =>  3:00
+CLOCK: [2017-10-08 Sun 09:00]--[2017-10-08 Sun 13:00] =>  4:00
+CLOCK: [2017-10-09 Mon 09:00]--[2017-10-09 Mon 14:00] =>  5:00"
+      (let ((system-time-locale "en_US"))
+	(test-org-clock-clocktable-contents
+	    ":step week :block 2017-10 :stepskip0 t")))))
+  ;; :step day
+  (should
+   (string-match-p
+    "
+.*?\\[2017-10-02 .*
+.*
+.*
+|.*?| \\*3:00\\* |
+.*
+| Foo +| 3:00 +|
+
+.*?\\[2017-10-03 .*
+.*
+.*
+|.*?| \\*0:00\\* |
+
+.*?\\[2017-10-04 .*
+.*
+.*
+|.*?| \\*0:00\\* |
+
+.*?\\[2017-10-05 .*
+.*
+.*
+|.*?| \\*0:00\\* |
+
+.*?\\[2017-10-06 .*
+.*
+.*
+|.*?| \\*0:00\\* |
+
+.*?\\[2017-10-07 .*
+.*
+.*
+|.*?| \\*0:00\\* |
+
+.*?\\[2017-10-08 .*
+.*
+.*
+|.*?| \\*4:00\\* |
+.*
+| Foo +| 4:00 +|"
+    (org-test-with-temp-text
+	"* Foo
+CLOCK: [2017-09-30 Sat 12:00]--[2017-09-30 Sat 13:00] =>  1:00
+CLOCK: [2017-10-01 Sun 11:00]--[2017-10-01 Sun 13:00] =>  2:00
+CLOCK: [2017-10-02 Mon 11:00]--[2017-10-02 Mon 14:00] =>  3:00
+CLOCK: [2017-10-08 Sun 09:00]--[2017-10-08 Sun 13:00] =>  4:00
+CLOCK: [2017-10-09 Mon 09:00]--[2017-10-09 Mon 14:00] =>  5:00"
+      (let ((system-time-locale "en_US"))
+	(test-org-clock-clocktable-contents
+	    ":step day :block 2017-W40")))))
+  ;; Regression test: take :tstart and :tend hours into consideration.
+  (should
+   (string-match-p
+    "
+.*?\\[2017-12-25 .*
+.*
+.*
+|.*?| \\*8:00\\* |
+.*
+| Foo +| 8:00 +|"
+    (org-test-with-temp-text
+	"* Foo
+CLOCK: [2017-12-27 Wed 08:00]--[2017-12-27 Wed 16:00] =>  8:00"
+      (let ((system-time-locale "en_US"))
+	(test-org-clock-clocktable-contents
+	    (concat ":step week :tstart \"<2017-12-25 Mon>\" "
+		    ":tend \"<2017-12-27 Wed 23:59>\""))))))
+  (should
+   (string-match-p
+    "
+.*?\\[2017-12-27 .*
+.*
+.*
+|.*?| \\*8:00\\* |
+.*
+| Foo +| 8:00 +|"
+    (org-test-with-temp-text
+	"* Foo
+CLOCK: [2017-12-27 Wed 08:00]--[2017-12-27 Wed 16:00] =>  8:00"
+      (let ((system-time-locale "en_US"))
+	(test-org-clock-clocktable-contents
+	    (concat ":step day :tstart \"<2017-12-25 Mon>\" "
+		    ":tend \"<2017-12-27 Wed 23:59>\" :stepskip0 t"))))))
+  ;; Test :step week", without or with ":wstart" parameter.
+  (should
+   (string-match-p
+    "
+.*?\\[2012-03-26 .*
+.*
+.*
+|.*?| \\*8:00\\* |
+.*
+| Foo +| 8:00 +|
+
+.*?\\[2012-04-02 .*
+.*
+.*
+|.*?| \\*8:00\\* |
+.*
+| Foo +| 8:00 +|
+"
+    (org-test-with-temp-text
+        "* Foo
+CLOCK: [2012-03-29 Thu 08:00]--[2012-03-29 Thu 16:00] =>  8:00
+CLOCK: [2012-04-03 Thu 08:00]--[2012-04-03 Thu 16:00] =>  8:00"
+      (let ((system-time-locale "en_US"))
+        (test-org-clock-clocktable-contents
+	    ":step week :block 2012 :stepskip0 t")))))
+  (should
+   (string-match-p
+    "
+.*?\\[2012-03-29 .*
+.*
+.*
+|.*?| \\*16:00\\* |
+.*
+| Foo +| 16:00 +|
+"
+    (org-test-with-temp-text
+        "* Foo
+CLOCK: [2012-03-29 Thu 08:00]--[2012-03-29 Thu 16:00] =>  8:00
+CLOCK: [2012-04-03 Thu 08:00]--[2012-04-03 Thu 16:00] =>  8:00"
+      (let ((system-time-locale "en_US"))
+        (test-org-clock-clocktable-contents
+	    ":step week :wstart 4 :block 2012 :stepskip0 t")))))
+  ;; Test ":step month" without and with ":mstart".
+  (should
+   (string-match-p
+    "
+.*?\\[2014-03-01 .*
+.*
+.*
+|.*?| \\*8:00\\* |
+.*
+| Foo +| 8:00 +|
+
+.*?\\[2014-04-01 .*
+.*
+.*
+|.*?| \\*8:00\\* |
+.*
+| Foo +| 8:00 +|
+"
+    (org-test-with-temp-text
+        "* Foo
+CLOCK: [2014-03-04 Tue 08:00]--[2014-03-04 Tue 16:00] =>  8:00
+CLOCK: [2014-04-03 Thu 08:00]--[2014-04-03 Thu 16:00] =>  8:00"
+      (let ((system-time-locale "en_US"))
+        (test-org-clock-clocktable-contents
+	    ":step month :block 2014 :stepskip0 t")))))
+  (should
+   (string-match-p
+    "
+.*?\\[2014-03-04 .*
+.*
+.*
+|.*?| \\*16:00\\* |
+.*
+| Foo +| 16:00 +|
+"
+    (org-test-with-temp-text
+        "* Foo
+CLOCK: [2014-03-04 Tue 08:00]--[2014-03-04 Tue 16:00] =>  8:00
+CLOCK: [2014-04-03 Thu 08:00]--[2014-04-03 Thu 16:00] =>  8:00"
+      (let ((system-time-locale "en_US"))
+        (test-org-clock-clocktable-contents
+	    ":step month :mstart 4 :block 2014 :stepskip0 t")))))
+  ;; Test ":step semimonth".
+  (should
+   (string-match-p
+    "
+.*?\\[2014-03-01 .*
+.*
+.*
+|.*?| \\*8:00\\* |
+.*
+| Foo +| 8:00 +|
+
+.*?\\[2014-03-16 .*
+.*
+.*
+|.*?| \\*2:00\\* |
+.*
+| Foo +| 2:00 +|
+
+.*?\\[2014-04-01 .*
+.*
+.*
+|.*?| \\*7:00\\* |
+.*
+| Foo +| 7:00 +|
+"
+    (org-test-with-temp-text
+     "* Foo
+CLOCK: [2014-03-04 Tue 08:00]--[2014-03-04 Tue 16:00] =>  8:00
+CLOCK: [2014-03-24 Mon 08:00]--[2014-03-24 Mon 10:00] =>  2:00
+CLOCK: [2014-04-03 Thu 08:00]--[2014-04-03 Thu 15:00] =>  7:00"
+     (let ((system-time-locale "en_US"))
+       (test-org-clock-clocktable-contents
+	":step semimonth :block 2014 :stepskip0 t")))))
+  ;; Test ":step year".
+  (should
+   (string-match-p
+    "
+.*?\\[2012-01-01 .*
+.*
+.*
+|.*?| \\*8:00\\* |
+.*
+| Foo +| 8:00 +|
+
+.*?\\[2014-01-01 .*
+.*
+.*
+|.*?| \\*8:00\\* |
+.*
+| Foo +| 8:00 +|
+"
+    (org-test-with-temp-text
+        "* Foo
+CLOCK: [2012-03-29 Thu 08:00]--[2012-03-29 Thu 16:00] =>  8:00
+CLOCK: [2014-03-04 Tue 08:00]--[2014-03-04 Tue 16:00] =>  8:00"
+      (let ((system-time-locale "en_US"))
+        (test-org-clock-clocktable-contents
+	    ":step year :block untilnow :stepskip0 t")))))
+  ;; Regression test: Respect DST
+  (should
+   (string-match-p
+    "
+.*?\\[2018-10-29 .*
+.*
+.*
+|.*?| \\*8:00\\* |
+.*
+| Foo +| 8:00 +|
+"
+    (org-test-with-temp-text
+        "* Foo
+CLOCK: [2018-10-29 Mon 08:00]--[2018-10-29 Mon 16:00] =>  8:00"
+      (let ((system-time-locale "en_US"))
+        (test-org-clock-clocktable-contents
+	    (concat ":step day "
+		    ":stepskip0 t "
+		    ":tstart \"2018-10-01\" "
+		    ":tend \"2018-11-01\"")))))))
+
+(ert-deftest test-org-clock/clocktable/extend-today-until ()
+  "Test assignment of clock time to days in presence of \"org-extend-today-until\"."
+  ;; Basic test of :block with org-extend-today-until - the report for
+  ;; 2017-09-30 should include the time clocked on 2017-10-01 before
+  ;; 04:00.
+  (should
+   (equal "| Headline     | Time   |
 |--------------+--------|
 | *Total time* | *2:00* |
 |--------------+--------|
-| Foo          | 2:00   |
+| Foo          | 2:00   |"
+          (org-test-with-temp-text
+              "* Foo
+CLOCK: [2017-09-30 Sat 12:00]--[2017-09-30 Sat 13:00] =>  1:00
+CLOCK: [2017-10-01 Sun 02:00]--[2017-10-01 Sun 03:00] =>  1:00
+CLOCK: [2017-10-01 Sun 11:00]--[2017-10-01 Sun 13:00] =>  2:00"
+            (setq-local org-extend-today-until 4)
+            (let ((system-time-locale "en_US"))
+              (test-org-clock-clocktable-contents
+               ":block 2017-09-30")))))
 
-Weekly report starting on: [2017-10-02 Mon]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *7:00* |
-|--------------+--------|
-| Foo          | 7:00   |
+  ;; Week-length block - time on Monday before 04:00 should be
+  ;; assigned to previous week.
+  (should
+   (string-match-p "
+.*? \\[2017-10-01 .*
+.*
+.*
+|.*?| \\*2:00\\* |
+.*
+| Foo +| 2:00   |
 
-Weekly report starting on: [2017-10-09 Mon]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *5:00* |
-|--------------+--------|
-| Foo          | 5:00   |
+.*? \\[2017-10-02 .*
+.*
+.*
+|.*?| \\*2:00\\* |
+.*
+| Foo +| 2:00   |
 "
-	  (org-test-with-temp-text
-	      "* Foo
-CLOCK: [2017-09-30 Sat 12:00]--[2017-09-30 Sat 13:00] =>  1:00
-CLOCK: [2017-10-01 Sun 11:00]--[2017-10-01 Sun 13:00] =>  2:00
-CLOCK: [2017-10-02 Mon 11:00]--[2017-10-02 Mon 14:00] =>  3:00
-CLOCK: [2017-10-08 Sun 09:00]--[2017-10-08 Sun 13:00] =>  4:00
-CLOCK: [2017-10-09 Mon 09:00]--[2017-10-09 Mon 14:00] =>  5:00"
-	    (let ((system-time-locale "en_US"))
-	      (test-org-clock-clocktable-contents
-		  ":step week :block 2017-10 :stepskip0 t")))))
-  ;; :step day
+          (org-test-with-temp-text
+              "* Foo
+CLOCK: [2017-10-01 Sun 12:00]--[2017-10-01 Sun 13:00] =>  1:00
+CLOCK: [2017-10-02 Mon 02:00]--[2017-10-02 Mon 03:00] =>  1:00
+CLOCK: [2017-10-02 Mon 11:00]--[2017-10-02 Mon 13:00] =>  2:00"
+            (setq-local org-extend-today-until 4)
+            (let ((system-time-locale "en_US"))
+              (test-org-clock-clocktable-contents
+               ":step week :block 2017-10 :stepskip0 t"))))))
+
+(ert-deftest test-org-clock/clocktable/hidefiles ()
+  "Test \":hidefiles\" parameter in Clock table."
+  ;; Test that hidefiles removes the file column.
   (should
-   (equal "
-Daily report: [2017-10-02 Mon]
-| Headline     | Time   |
+   (equal
+    "| Headline     | Time   |
 |--------------+--------|
-| *Total time* | *3:00* |
+| *Total time* | *1:00* |
 |--------------+--------|
-| Foo          | 3:00   |
-
-Daily report: [2017-10-03 Tue]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *0:00* |
-
-Daily report: [2017-10-04 Wed]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *0:00* |
-
-Daily report: [2017-10-05 Thu]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *0:00* |
-
-Daily report: [2017-10-06 Fri]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *0:00* |
-
-Daily report: [2017-10-07 Sat]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *0:00* |
-
-Daily report: [2017-10-08 Sun]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *4:00* |
-|--------------+--------|
-| Foo          | 4:00   |"
-	  (org-test-with-temp-text
-	      "* Foo
-CLOCK: [2017-09-30 Sat 12:00]--[2017-09-30 Sat 13:00] =>  1:00
-CLOCK: [2017-10-01 Sun 11:00]--[2017-10-01 Sun 13:00] =>  2:00
-CLOCK: [2017-10-02 Mon 11:00]--[2017-10-02 Mon 14:00] =>  3:00
-CLOCK: [2017-10-08 Sun 09:00]--[2017-10-08 Sun 13:00] =>  4:00
-CLOCK: [2017-10-09 Mon 09:00]--[2017-10-09 Mon 14:00] =>  5:00"
-	    (let ((system-time-locale "en_US"))
-	      (test-org-clock-clocktable-contents
-		  ":step day :block 2017-W40")))))
-  ;; Regression test: take :tstart and :tend hours into consideration.
-  (should
-   (equal "
-Weekly report starting on: [2017-12-25 Mon]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *8:00* |
-|--------------+--------|
-| Foo          | 8:00   |"
-	  (org-test-with-temp-text
-	      "* Foo
-CLOCK: [2017-12-27 Wed 08:00]--[2017-12-27 Wed 16:00] =>  8:00"
-	    (let ((system-time-locale "en_US"))
-	      (test-org-clock-clocktable-contents
-		  (concat ":step week :tstart \"<2017-12-25 Mon>\" "
-			  ":tend \"<2017-12-27 Wed 23:59>\""))))))
-  (should
-   (equal "
-Daily report: [2017-12-27 Wed]
-| Headline     | Time   |
-|--------------+--------|
-| *Total time* | *8:00* |
-|--------------+--------|
-| Foo          | 8:00   |"
-	  (org-test-with-temp-text
-	      "* Foo
-CLOCK: [2017-12-27 Wed 08:00]--[2017-12-27 Wed 16:00] =>  8:00"
-	    (let ((system-time-locale "en_US"))
-	      (test-org-clock-clocktable-contents
-		  (concat ":step day :tstart \"<2017-12-25 Mon>\" "
-			  ":tend \"<2017-12-27 Wed 23:59>\" :stepskip0 t")))))))
+| Test         | 1:00   |"
+    (org-test-with-temp-text-in-file
+        "* Test
+CLOCK: [2012-03-29 Thu 16:00]--[2012-03-29 Thu 17:00] =>  1:00"
+      (let ((the-file (buffer-file-name)))
+        (org-test-with-temp-text-in-file ""
+          (test-org-clock-clocktable-contents
+           (format ":hidefiles t :scope (lambda () (list %S))" the-file))))))))
 
 (provide 'test-org-clock)
 ;;; test-org-clock.el end here
